@@ -1,28 +1,3 @@
-/// Used to compare serialized structures
-#[doc(hidden)]
-#[macro_export]
-#[cfg(test)]
-macro_rules! test_serialization {
-    (
-        $(
-            $name:ident($subject:expr, $expectation:expr)
-        );+
-        $(;)?
-    ) => {
-        use serde_json::{json, Value, to_string, from_str};
-
-        $(
-            #[test]
-            fn $name() {
-                let string = to_string(&$subject).unwrap();
-                let result: Value = from_str(&string).unwrap();
-
-                assert_eq!(result, $expectation);
-            }
-        )+
-    };
-}
-
 #[doc(hidden)]
 #[macro_export]
 macro_rules! add_boost_and_name {
@@ -37,7 +12,10 @@ macro_rules! add_boost_and_name {
         /// Boost values are relative to the default value of `1.0`.
         /// A boost value between 0 and `1.0` decreases the relevance score.
         /// A value greater than `1.0` increases the relevance score.
-        pub fn boost(mut self, boost: impl std::convert::TryInto<Boost>) -> Self {
+        pub fn boost<B>(mut self, boost: B) -> Self
+        where
+            B: std::convert::TryInto<Boost>,
+        {
             if let Ok(boost) = boost.try_into() {
                 self.inner.boost = Some(boost);
             }
@@ -49,8 +27,11 @@ macro_rules! add_boost_and_name {
         /// includes a `matched_queries` property for each hit.
         ///
         /// <https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-bool-query.html#named-queries>
-        pub fn name(mut self, name: impl Into<String>) -> Self {
-            self.inner._name = Some(name.into());
+        pub fn name<S>(mut self, name: S) -> Self
+        where
+            S: ToString,
+        {
+            self.inner._name = Some(name.to_string());
             self
         }
     };
@@ -61,9 +42,13 @@ macro_rules! add_boost_and_name {
 macro_rules! add_aggregate {
     () => {
         /// Pushes aggregation
-        pub fn aggregate(mut self, aggregation: impl Into<Aggregation>) -> Self {
+        pub fn aggregate<N, A>(mut self, aggregation_name: N, aggregation: A) -> Self
+        where
+            N: Into<AggregationName>,
+            A: Into<Aggregation>,
+        {
             let a = aggregation.into();
-            let _ = self.aggs.entry(a.name()).or_insert(a);
+            let _ = self.aggs.entry(aggregation_name.into()).or_insert(a);
             self
         }
     };
