@@ -11,6 +11,12 @@ pub struct Search {
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
     runtime_mappings: BTreeMap<String, RuntimeMapping>,
 
+    #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
+    indices_boost: Vec<KeyValuePair<String, Boost>>,
+
+    #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
+    min_score: Option<f32>,
+
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
     _source: Option<SourceFilter>,
 
@@ -57,6 +63,35 @@ impl Search {
         self
     }
 
+    /// Allows to configure different boost level per index when searching
+    /// across more than one indices. This is very handy when hits coming from
+    /// one index matter more than hits coming from another index (think social
+    /// graph where each user has an index).
+    pub fn indices_boost<F, B>(mut self, field: F, boost: B) -> Self
+    where
+        F: ToString,
+        B: TryInto<Boost>,
+    {
+        if let Ok(boost) = boost.try_into() {
+            self.indices_boost
+                .push(KeyValuePair::new(field.to_string(), boost));
+        }
+        self
+    }
+
+    /// Exclude documents which have a `_score` less than the minimum specified
+    /// in `min_score`
+    ///
+    /// Note, most times, this does not make much sense, but is provided for
+    /// advanced use cases
+    pub fn min_score<F>(mut self, min_score: F) -> Self
+    where
+        F: Into<f32>,
+    {
+        self.min_score = Some(min_score.into());
+        self
+    }
+
     /// Indicates which source fields are returned for matching documents
     pub fn source<S>(mut self, source: S) -> Self
     where
