@@ -1,9 +1,12 @@
 //! Module containing helpers and util functions that are not specific to any DSL
 
+mod assert_serialize;
 mod join_with_pipe;
 mod key_value_pair;
 mod should_skip;
 
+#[cfg(test)]
+pub(crate) use self::assert_serialize::*;
 pub(crate) use self::join_with_pipe::*;
 pub(crate) use self::key_value_pair::*;
 pub(crate) use self::should_skip::*;
